property_value_alias_sc_long_to_short = {
    "Adlam": "Adlm",
    "Ahom": "Ahom",
    "Anatolian_Hieroglyphs": "Hluw",
    "Arabic": "Arab",
    "Armenian": "Armn",
    "Avestan": "Avst",
    "Balinese": "Bali",
    "Bamum": "Bamu",
    "Bassa_Vah": "Bass",
    "Batak": "Batk",
    "Bengali": "Beng",
    "Bhaiksuki": "Bhks",
    "Bopomofo": "Bopo",
    "Brahmi": "Brah",
    "Braille": "Brai",
    "Buginese": "Bugi",
    "Buhid": "Buhd",
    "Canadian_Aboriginal": "Cans",
    "Carian": "Cari",
    "Caucasian_Albanian": "Aghb",
    "Chakma": "Cakm",
    "Cham": "Cham",
    "Cherokee": "Cher",
    "Chorasmian": "Chrs",
    "Common": "Zyyy",
    "Coptic": "Copt",
    "Cuneiform": "Xsux",
    "Cypriot": "Cprt",
    "Cyrillic": "Cyrl",
    "Deseret": "Dsrt",
    "Devanagari": "Deva",
    "Dives_Akuru": "Diak",
    "Dogra": "Dogr",
    "Duployan": "Dupl",
    "Egyptian_Hieroglyphs": "Egyp",
    "Elbasan": "Elba",
    "Elymaic": "Elym",
    "Ethiopic": "Ethi",
    "Georgian": "Geor",
    "Glagolitic": "Glag",
    "Gothic": "Goth",
    "Grantha": "Gran",
    "Greek": "Grek",
    "Gujarati": "Gujr",
    "Gunjala_Gondi": "Gong",
    "Gurmukhi": "Guru",
    "Han": "Hani",
    "Hangul": "Hang",
    "Hanifi_Rohingya": "Rohg",
    "Hanunoo": "Hano",
    "Hatran": "Hatr",
    "Hebrew": "Hebr",
    "Hiragana": "Hira",
    "Imperial_Aramaic": "Armi",
    "Inherited": "Zinh",
    "Inscriptional_Pahlavi": "Phli",
    "Inscriptional_Parthian": "Prti",
    "Javanese": "Java",
    "Kaithi": "Kthi",
    "Kannada": "Knda",
    "Katakana": "Kana",
    "Katakana_Or_Hiragana": "Hrkt",
    "Kayah_Li": "Kali",
    "Kharoshthi": "Khar",
    "Khitan_Small_Script": "Kits",
    "Khmer": "Khmr",
    "Khojki": "Khoj",
    "Khudawadi": "Sind",
    "Lao": "Laoo",
    "Latin": "Latn",
    "Lepcha": "Lepc",
    "Limbu": "Limb",
    "Linear_A": "Lina",
    "Linear_B": "Linb",
    "Lisu": "Lisu",
    "Lycian": "Lyci",
    "Lydian": "Lydi",
    "Mahajani": "Mahj",
    "Makasar": "Maka",
    "Malayalam": "Mlym",
    "Mandaic": "Mand",
    "Manichaean": "Mani",
    "Marchen": "Marc",
    "Masaram_Gondi": "Gonm",
    "Medefaidrin": "Medf",
    "Meetei_Mayek": "Mtei",
    "Mende_Kikakui": "Mend",
    "Meroitic_Cursive": "Merc",
    "Meroitic_Hieroglyphs": "Mero",
    "Miao": "Plrd",
    "Modi": "Modi",
    "Mongolian": "Mong",
    "Mro": "Mroo",
    "Multani": "Mult",
    "Myanmar": "Mymr",
    "Nabataean": "Nbat",
    "Nandinagari": "Nand",
    "New_Tai_Lue": "Talu",
    "Newa": "Newa",
    "Nko": "Nkoo",
    "Nushu": "Nshu",
    "Nyiakeng_Puachue_Hmong": "Hmnp",
    "Ogham": "Ogam",
    "Ol_Chiki": "Olck",
    "Old_Hungarian": "Hung",
    "Old_Italic": "Ital",
    "Old_North_Arabian": "Narb",
    "Old_Permic": "Perm",
    "Old_Persian": "Xpeo",
    "Old_Sogdian": "Sogo",
    "Old_South_Arabian": "Sarb",
    "Old_Turkic": "Orkh",
    "Oriya": "Orya",
    "Osage": "Osge",
    "Osmanya": "Osma",
    "Pahawh_Hmong": "Hmng",
    "Palmyrene": "Palm",
    "Pau_Cin_Hau": "Pauc",
    "Phags_Pa": "Phag",
    "Phoenician": "Phnx",
    "Psalter_Pahlavi": "Phlp",
    "Rejang": "Rjng",
    "Runic": "Runr",
    "Samaritan": "Samr",
    "Saurashtra": "Saur",
    "Sharada": "Shrd",
    "Shavian": "Shaw",
    "Siddham": "Sidd",
    "SignWriting": "Sgnw",
    "Sinhala": "Sinh",
    "Sogdian": "Sogd",
    "Sora_Sompeng": "Sora",
    "Soyombo": "Soyo",
    "Sundanese": "Sund",
    "Syloti_Nagri": "Sylo",
    "Syriac": "Syrc",
    "Tagalog": "Tglg",
    "Tagbanwa": "Tagb",
    "Tai_Le": "Tale",
    "Tai_Tham": "Lana",
    "Tai_Viet": "Tavt",
    "Takri": "Takr",
    "Tamil": "Taml",
    "Tangut": "Tang",
    "Telugu": "Telu",
    "Thaana": "Thaa",
    "Thai": "Thai",
    "Tibetan": "Tibt",
    "Tifinagh": "Tfng",
    "Tirhuta": "Tirh",
    "Ugaritic": "Ugar",
    "Unknown": "Zzzz",
    "Vai": "Vaii",
    "Wancho": "Wcho",
    "Warang_Citi": "Wara",
    "Yezidi": "Yezi",
    "Yi": "Yiii",
    "Zanabazar_Square": "Zanb",
}
